pub struct RuntimeRoomStatsSnapshot {
pub create_date: String,
pub uuid: String,
pub remote_address: String,
pub users_stats: RoomUserStatsSnapshot,
pub web_rtc_enabled: bool,
}Expand description
operator-facing room stats assembled from directory and transport snapshots
Fields
create_date: Stringroom publication timestamp in RFC 3339 UTC format
uuid: Stringroom uuid returned by /v1/channel
remote_address: Stringfirst create request address or unknown when unavailable
users_stats: RoomUserStatsSnapshotlive user, stream and bitrate stats read after the directory snapshot
web_rtc_enabled: boolroom creation flag exposed by /v1/stats